Spinmob: 
 * Easy data loading / saving.
 * High-level pylab-based plotting
 * Fitting and other data analysis
 * Simplified GUI objects based on pyqtgraph

See http://github.com/Spinmob/spinmob for more information.
